#include "ethernet.h"
#include "status_codes.h"
#include "conf_uart_serial.h"
#include "uart_serial.h"
#include "stdio_serial.h"
#include "tc.h"

#include "sysclk.h"
#include "lwip/opt.h"
#include "lwip/tcpip.h"

#include "lwip/stats.h"
#include "lwip/sys.h"
#include "lwip/api.h"
#include "lwip/sockets.h"
#include "RIO2014_USART.h"

#define USART_PORT_1		USART0	//RS-485 Only
#define USART_PORT_2		USART1	//RS-232 Only
#define	BAUDRATE		115200
#define	PARITY			US_MR_PAR_NO
#define CHAR_LENGTH     US_MR_CHRL_8_BIT
#define STOP_BIT		US_MR_NBSTOP_1_BIT

#define RBUF_MAX	128

static uint8_t AppVersion[] = "V1.001 #";

void user_main(void)
{
	uint8_t ret, rbuf[RBUF_MAX];
	uint16_t len;
	
	printf("E05 USART Echo %s(%s %s)\r\n", AppVersion, __DATE__, __TIME__);

	/*RS-485*/
	ret = serial_usart_open(USART_PORT_1, BAUDRATE, PARITY, CHAR_LENGTH, STOP_BIT);
	if (ret != USART_OK) {
		printf("usart_open failed:%d\r\n", ret);
		return;
	}	
	ret = serial_usart_set_read_timeout(USART_PORT_1, 1); //1ms
	if (ret != USART_OK) {
		printf("serial_usart_set_read_timeout failed:%d\r\n", ret);
		return;
	}	
	ret = serial_usart_set_write_timeout(USART_PORT_1, 1000); //1 second
	if (ret != USART_OK) {
		printf("serial_usart_set_write_timeout failed:%d\r\n", ret);
		return;
	}	
	serial_usart_write(USART_PORT_1, "RS-485 Ready\r\n", 14);
	
	/*RS-232*/
	ret = serial_usart_open(USART_PORT_2, BAUDRATE, PARITY, CHAR_LENGTH, STOP_BIT);
	if (ret != USART_OK) {
		printf("usart_open failed:%d\r\n", ret);
		return;
	}	
	ret = serial_usart_set_read_timeout(USART_PORT_2, 1); //1ms
	if (ret != USART_OK) {
		printf("serial_usart_set_read_timeout failed:%d\r\n", ret);
		return;
	}
	ret = serial_usart_set_write_timeout(USART_PORT_2, 1000); //1 second
	if (ret != USART_OK) {
		printf("serial_usart_set_write_timeout failed:%d\r\n", ret);
		return;
	}
	serial_usart_write(USART_PORT_2, "RS-232 Ready\r\n", 14);	
	for( ;; )
	{
		/*RS-485 echo*/
		len = serial_usart_read(USART_PORT_1, rbuf, 1);
		if (len > 0) {
			serial_usart_write(USART_PORT_1, rbuf, len);
		}
		/*RS-232 echo*/
		len = serial_usart_read(USART_PORT_2, rbuf, 1);
		if (len > 0) {
			serial_usart_write(USART_PORT_2, rbuf, len);
		}		
		vTaskDelay(1);		
	}
}
