#include <string.h>
#include "ethernet.h"
#include "status_codes.h"
#include "conf_uart_serial.h"
#include "uart_serial.h"
#include "stdio_serial.h"
#include "tc.h"

#include "sysclk.h"
#include "lwip/opt.h"
#include "lwip/tcpip.h"

#include "lwip/stats.h"
#include "lwip/sys.h"
#include "lwip/api.h"
#include "lwip/sockets.h"

#include "RIO2014_SPI_FLASH.h"

static uint8_t AppVersion[] = "V1.001 #";

#define BUFFER_LEN	256

static uint8_t write_buffer[BUFFER_LEN];
static uint8_t read_buffer[BUFFER_LEN];

void user_main(void)
{
	uint32_t start_address;
	uint16_t i, block_no, sector_no, page_no;
	uint8_t ret;
	
	printf("E07 SPI Flash %s(%s %s)\r\n", AppVersion, __DATE__, __TIME__);
	
	if (spi_flash_init() != SPI_FLASH_OK) {
		printf("SPI Flash init failed.\r\n");
		return -1;
	}

	printf("Read from the SPI Flash.\r\n");
	start_address = 0x1EF000;
	memset(read_buffer, 0, sizeof(read_buffer));
	ret = spi_flash_read(start_address, read_buffer, BUFFER_LEN);
	if (ret != SPI_FLASH_OK) {
		printf("read failed:%d.\r\n", ret);
		return -1;
	}
	for(i=0; i<16; i++) {
		printf("[%d]:%02X,", i, read_buffer[i]);
	}
	printf("\r\n");
	
	printf("Erase sector for write/read test.\r\n");
	sector_no = 495;
	ret = spi_flash_erase_sector(sector_no);
	if (ret != SPI_FLASH_OK) {
		printf("erase sector failed:%d\r\n", ret);
		return -1;
	}
	printf("Read from the SPI Flash.\r\n");
	memset(read_buffer, 0, sizeof(read_buffer));
	ret = spi_flash_read(start_address, read_buffer, BUFFER_LEN);
	if (ret != SPI_FLASH_OK) {
		printf("read page failed:%d.\r\n", ret);
		return -1;
	}
	for(i=0; i<16; i++) {
		printf("[%d]:%02X,", i, read_buffer[i]);
	}
	printf("\r\n");
	printf("Preparing a write data.\r\n");
	for (i = 0; i < BUFFER_LEN; i++) {
		write_buffer[i] = (i & 0xFF);
	}
	printf("Write a page to the SPI Flash.\r\n");
	page_no = 7920;
	ret = spi_flash_write_page(page_no, write_buffer, BUFFER_LEN);
	if (ret != SPI_FLASH_OK) {
		printf("write page failed:%d.\r\n", ret);
		return -1;
	}
	
	printf("Read from the SPI Flash.\r\n");
	memset(read_buffer, 0, sizeof(read_buffer));
	ret = spi_flash_read(start_address, read_buffer, BUFFER_LEN);
	if (ret != SPI_FLASH_OK) {
		printf("read page failed:%d.\r\n", ret);
		return -1;
	}
	for(i=0; i<16; i++) {
		printf("[%d]:%02X,", i, read_buffer[i]);
	}
	printf("\r\n");	
	/* Test if the read buffer is the same as SRAM buffer */
	printf("Test if the read buffer is the same as the write buffer.\r\n");
	ret = memcmp(read_buffer, write_buffer, sizeof(write_buffer));
	if (ret) {
		printf("Read data is different from write data in page %d.\r\n",	page_no);
		} else {
		printf("Read data matches write data in page %d.\r\n",	page_no);
	}
	
	for( ;; )
	{
		vTaskDelay(5000);		
	}

}
