#include "ethernet.h"
#include "status_codes.h"
#include "conf_uart_serial.h"
#include "uart_serial.h"
#include "stdio_serial.h"
#include "tc.h"

#include "sysclk.h"
#include "lwip/opt.h"
#include "lwip/tcpip.h"

#include "lwip/stats.h"
#include "lwip/sys.h"
#include "lwip/api.h"
#include "lwip/sockets.h"
#include "RIO2014_SD.h"
#include <string.h>

/** Size of the file to write/read. */
#define DATA_SIZE 64

static uint8_t AppVersion[] = "V1.001 #";
static char c_lfn[_MAX_LFN + 1];
TCHAR root_directory[3] = "0:";
static char test_file_name[] = "0:sd_mmc_test.txt";
/**
 * \brief Scan files under a certain path.
 *
 * \param path Folder path.
 *
 * \return Scan result, 1: success.
 */
static FRESULT scan_files(char *path)
{
	FRESULT res;
	FILINFO fno;
	DIR dir;
	int32_t i;
	char *pc_fn;
	
	fno.lfname = c_lfn;
	fno.lfsize = sizeof(c_lfn);

	/* Open the directory */
	res = f_opendir(&dir, path);
	if (res == FR_OK) {
		i = strlen(path);
		for (;;) {
			res = f_readdir(&dir, &fno);
			if (res != FR_OK || fno.fname[0] == 0) {
				break;
			}

			pc_fn = *fno.lfname ? fno.lfname : fno.fname;
			if (*pc_fn == '.') {
				continue;
			}

			/* Check if it is a directory type */
			if (fno.fattrib & AM_DIR) {
				sprintf(&path[i], "/%s", pc_fn);
				res = scan_files(path);
				if (res != FR_OK) {
					break;
				}

				path[i] = 0;
			} else {
				printf("%s/%s\n\r", path, pc_fn);
			}
		}
	}

	return res;
}
static uint8_t dump_file_content(char *file_name)
{
	FIL file_object;
	uint8_t i, data_buffer[DATA_SIZE];
	uint16_t byte_to_read;
	uint16_t byte_read;
	FRESULT res;
	
	/* Open the file */
	printf("Open file: \"%s\"\r\n", file_name);
	res = f_open(&file_object, (char const *)file_name,
	FA_OPEN_EXISTING | FA_READ);
	if (res != FR_OK) {
		printf("f_open failed: 0x%X\n\r", res);
		return 0;
	}

	/* Read file */
	memset(data_buffer, 0, DATA_SIZE);
	byte_to_read = file_object.fsize;
	printf("Content:\r\n");
	for (i = 0; i < byte_to_read; i += DATA_SIZE) {
		res = f_read(&file_object, data_buffer, DATA_SIZE, &byte_read);
		if (res != FR_OK) {
			printf("f_read failed: 0x%X\n\r", res);
			return 0;
		}
		data_buffer[byte_read] = 0;
		printf("%s", data_buffer);
	}

	/* Close the file*/
	puts("\r\nClose file\r\n");
	res = f_close(&file_object);
	if (res != FR_OK) {
		printf("f_close failed: 0x%X\n\r", res);
		return 0;
	}
	return 1;
}

void user_main(void)
{	
	FRESULT res;
	FIL file_object;
	
	printf("E08 SD Card %s(%s %s)\r\n", AppVersion, __DATE__, __TIME__);
	
	printf("Please plug an SD card in slot and wait for mount ok.\n\r");
	
	while(!is_sd_present()){vTaskDelay(1);}
	
	printf("scan_files...\r\n");	
	scan_files((char *)root_directory);
	dump_file_content(test_file_name);
	
	printf("Create file %s...", test_file_name);
	res = f_open(&file_object,
		(char const *)test_file_name,
		FA_CREATE_ALWAYS | FA_WRITE);
	if (res != FR_OK) {
		printf("failed res %d\r\n", res);
		return -1;
	}
	printf("OK\r\n");

	printf("Write to test file...");
	if (0 == f_puts("Test SD/MMC Example\n", &file_object)) {
		f_close(&file_object);
		printf("failed\r\n");
		return -1;
	}
	printf("OK\r\n");
	f_close(&file_object);
	printf("Test is successful.\n\r");	

	for( ;; )
	{
		vTaskDelay(1000);
	}
}
