#include <string.h>
#include "ethernet.h"
#include "status_codes.h"
#include "conf_uart_serial.h"
#include "uart_serial.h"
#include "stdio_serial.h"
#include "tc.h"

#include "sysclk.h"
#include "lwip/opt.h"
#include "lwip/tcpip.h"

#include "lwip/stats.h"
#include "lwip/sys.h"
#include "lwip/api.h"
#include "lwip/sockets.h"

#include "RIO2014_EEPROM.h"

static uint8_t AppVersion[] = "V1.001 #";

static uint8_t write_buffer[16];
static uint8_t read_buffer[16];

/*
total size: 2048 bytes
*/
void user_main(void)
{
	uint32_t ret;
	uint16_t i, address;
	
	printf("E09 EEPROM %s(%s %s)\r\n", AppVersion, __DATE__, __TIME__);

	address = 2032;
	memset(read_buffer, 0, sizeof(read_buffer));
	printf("Read from EEPROM.\r\n");
	ret = rio_eeprom_read(address, read_buffer, 16);
	if (ret != EEPROM_OK) {
		printf("read eeprom failed:%d.\r\n", ret);
		return -1;
	}	
	for(i=0; i<16; i++) {
		printf("[%d]:%02X,", i, read_buffer[i]);
	}
	printf("\r\n");	
	
	printf("Preparing a write data.\r\n");
	for (i = 0; i < 16; i++) {
		write_buffer[i] = i;
	}
	printf("Write to EEPROM.\r\n");	
	ret = rio_eeprom_write_page(address, write_buffer, 16);
	if (ret != EEPROM_OK) {
		printf("write eeprom failed:%d.\r\n", ret);
		return -1;
	}
	vTaskDelay(1000);	
	memset(read_buffer, 0, sizeof(read_buffer));
	printf("Read from EEPROM.\r\n");
	ret = rio_eeprom_read(address, read_buffer, 16);
	if (ret != EEPROM_OK) {
		printf("read eeprom failed:%d.\r\n", ret);
		return -1;
	}	
	for(i=0; i<16; i++) {
		printf("[%d]:%02X,", i, read_buffer[i]);
	}
	printf("\r\n");	
		/* Test if the read buffer is the same as SRAM buffer */
	printf("Test if the read buffer is the same as the write buffer.\r\n");
	ret = memcmp(read_buffer, write_buffer, sizeof(write_buffer));
	if (ret) {
		printf("Read data is different from write data in address:%d.\r\n",	address);
	} else {
		printf("Read data matches write data in address:%d.\r\n",	address);
	}			
	for( ;; )
	{		
		vTaskDelay(1000);		
	}
}
