#include <string.h>
#include "ethernet.h"
#include "status_codes.h"
#include "conf_uart_serial.h"
#include "uart_serial.h"
#include "stdio_serial.h"
#include "tc.h"

#include "sysclk.h"
#include "lwip/opt.h"
#include "lwip/tcpip.h"

#include "lwip/stats.h"
#include "lwip/sys.h"
#include "lwip/api.h"
#include "lwip/sockets.h"

#include "RIO2014_SPI_SRAM.h"

static uint8_t AppVersion[] = "V1.001 #";

#define BUFFER_LEN	32

static uint8_t write_buffer[BUFFER_LEN];
static uint8_t read_buffer[BUFFER_LEN];

void user_main(void)
{
	uint32_t start_address;
	uint16_t i;
	uint8_t ret;
	
	printf("E10 SPI SRAM %s(%s %s)\r\n", AppVersion, __DATE__, __TIME__);

	if (spi_sram_init() != SPI_SRAM_OK) {
		printf("SPI SRAM init failed.\r\n");
		return;
	}

	printf("Read from the SPI SRAM.\r\n");
	start_address = 0x000101;
	memset(read_buffer, 0, sizeof(read_buffer));
	ret = spi_sram_read(start_address, read_buffer, BUFFER_LEN);
	if (ret != SPI_SRAM_OK) {
		printf("read failed:%d.\r\n", ret);
		return;
	}
	for(i=0; i<16; i++) {
		printf("[%d]:%02X,", i, read_buffer[i]);
	}
	printf("\r\n");
	
	printf("Preparing a write data.\r\n");
	for (i = 0; i < BUFFER_LEN; i++) {
		write_buffer[i] = (i & 0xFF);
	}
	printf("Write a page to the SPI SRAM.\r\n");
	ret = spi_sram_write(start_address, write_buffer, BUFFER_LEN);
	if (ret != SPI_SRAM_OK) {
		printf("write page failed:%d.\r\n", ret);
		return;
	}
	
	printf("Read from the SPI SRAM.\r\n");
	memset(read_buffer, 0, sizeof(read_buffer));
	ret = spi_sram_read(start_address, read_buffer, BUFFER_LEN);
	if (ret != SPI_SRAM_OK) {
		printf("read failed:%d.\r\n", ret);
		return;
	}
	for(i=0; i<16; i++) {
		printf("[%d]:%02X,", i, read_buffer[i]);
	}
	printf("\r\n");	
	/* Test if the read buffer is the same as SRAM buffer */
	printf("Test if the read buffer is the same as the write buffer.\r\n");
	ret = memcmp(read_buffer, write_buffer, sizeof(write_buffer));
	if (ret) {
		printf("Read data is different from write data in address 0x%lX\r\n", start_address);
		} else {
		printf("Read data matches write data in address 0x%lX\r\n", start_address);
	}

	for( ;; )
	{
		vTaskDelay(5000);		
	}

}
