#include "ethernet.h"
#include "status_codes.h"
#include "conf_uart_serial.h"
#include "uart_serial.h"
#include "stdio_serial.h"
#include "tc.h"

#include "sysclk.h"
#include "lwip/opt.h"
#include "lwip/tcpip.h"

#include "lwip/stats.h"
#include "lwip/sys.h"
#include "lwip/api.h"
#include "lwip/sockets.h"
#include "MQTTPacket.h"
#include "transport.h"
#include "RIO2014_SYSTEM.h"
#include "RIO2014_1WIRE_SENSOR.h"
#include "RIO2014.h"

static uint8_t AppVersion[] = "V1.001 #";

static char payload[128];
static unsigned char buf[128];
static uint8_t sensor_id[8];
static float sensor_value;
static char id_str[64];

uint8_t get_sensor_value(char *databuf)
{
	uint8_t i, j, ret, float_str[16], sensor_count;
	float value_f;
	uint8_t len=0;
	
	sensor_count = temperature_sensor_get_count();
	if (sensor_count == 0) {
		printf("No sensor online\r\n");
		return 0;
	}	
	len = sprintf(databuf, "{\"d\":{\"name\":\"%s\",", "RIO-2014PG");	
	for (j=0; j<sensor_count; j++) {
		ret = temperature_sensor_get_value(j, &sensor_id, &sensor_value);
		if (ret != SENSOR_OK) {
			printf("get value failed:%d\r\n", ret);
			return 0;
		}
		printf("Sensor#%d ID:", j);
		for (i = 0; i < 8; i++){
			printf("%02X", sensor_id[i]);
		}		
		ftoa(sensor_value, float_str, 2);
		printf(", %s C\r\n", float_str);
		len += sprintf(&databuf[len], "\"T#%d(C)\":%s,", j, float_str);
	}
	len--;
	len += sprintf(&databuf[len], "%s", "}}");	
	return len;
}

void user_main(void)
{	
	int ret;
	int rc = 0, mysock = 0, msgid = 1;
	int buflen = sizeof(buf);
	int req_qos[2] = {2, 1};	
	uint8_t mac_buf[6];			
	
	MQTTPacket_connectData data = MQTTPacket_connectData_initializer;
	MQTTString pub_topicString = MQTTString_initializer;
	MQTTString topicString[2] = { MQTTString_initializer, MQTTString_initializer };

	int payloadlen, len = 0;
	char *host = "184.172.124.189";//quickstart.internetofthings.ibmcloud.com
	int port = 1883;
	MQTTTransport mytransport;
	unsigned char dup;
	int qos, payloadlen_in;
	unsigned char retained;
	unsigned char* payload_in;
	MQTTString receivedTopic;
	unsigned short submsgid;
	int subcount, granted_qos, mode, tmpcnt = 0;	
	
	printf("E13 One Wire Sensor to IBM Bluemix quickstart %s(%s %s)\r\n", AppVersion, __DATE__, __TIME__);
	printf("Set DHCP mode first please.\r\n");
	ret = temperature_sensor_init();
	if (ret != SENSOR_OK) {
		printf("temperature_sensor_init failed:%d\r\n", ret);
		return -1;
	}

    while(1) {
	    printf("%s\r\n", "connecting...");
	    mysock = transport_open(host, port);
	    if(mysock >= 0) {
		    break;
	    }
	    vTaskDelay(1000);
    }	

    printf("%s\r\n", "connect ok");
	mode = 1;
	lwip_ioctl(mysock, FIONBIO, &mode);

	mytransport.sck = &mysock;
	mytransport.getfn = transport_getdatanb;
	mytransport.state = 0;		
	data.keepAliveInterval = 30;
	data.cleansession = 1;
	
	get_ethernet_mac(mac_buf);	
	sprintf(id_str, "d:quickstart:arduino:%02X%02X%02X%02X%02X%02X",
				(int)mac_buf[0], (int)mac_buf[1], (int)mac_buf[2],
				(int)mac_buf[3], (int)mac_buf[4], (int)mac_buf[5]);
	data.clientID.cstring = id_str;

	printf("%d Sending to hostname %s port %d\r\n", mysock, host, port);

	len = MQTTSerialize_connect(buf, buflen, &data);

	rc = transport_sendPacketBuffer(mysock, buf, len);
	printf("transport_send:%d\r\n", rc);

	while (1) {
		// wait for connack
		if (MQTTPacket_read(buf, buflen, transport_getdata) == CONNACK) {
			unsigned char sessionPresent, connack_rc;
			if (MQTTDeserialize_connack(&sessionPresent, &connack_rc, buf, buflen) != 1 || connack_rc != 0) {
				printf("Unable to connect, return code %d\n", connack_rc);
				goto exit;
			} else {
				break;
			}
		}
		vTaskDelay(10);
	}

	pub_topicString.cstring = "iot-2/evt/status/fmt/json";
	while (1) {
		payloadlen = get_sensor_value(payload);
		if (payloadlen > 0) {
			len = MQTTSerialize_publish(buf, buflen, 0, 0, 0, 0, pub_topicString, (unsigned char*)payload, payloadlen);       
			rc = transport_sendPacketBuffer(mysock, buf, len);
		}
		vTaskDelay(2000);		
	}
exit:
	transport_close(mysock);
	return -1;
}
