#include <stdio.h>
#include <string.h>
#include "asf.h"
#include "lwip/opt.h"
#include "lwip/tcpip.h"

#include "lwip/stats.h"
#include "lwip/sys.h"
#include "lwip/api.h"
#include "lwip/sockets.h"

#if !defined(SOCKET_ERROR)
	// error in socket operation
	#define SOCKET_ERROR -1
#endif

#define INVALID_SOCKET SOCKET_ERROR

/**
This simple low-level implementation assumes a single connection for a single thread. Thus, a static
variable is used for that connection.
On other scenarios, the user must solve this by taking into account that the current implementation of
MQTTPacket_read() has a function pointer for a function call to get the data to a buffer, but no provisions
to know the caller or other indicator (the socket id): int (*getfn)(unsigned char*, int)
*/
static int mysock = INVALID_SOCKET;

int transport_sendPacketBuffer(int sock, unsigned char* buf, int buflen)
{
	int rc = 0;
//	rc = write(sock, buf, buflen);
	rc = send(sock, buf, buflen, 0);
	return rc;
}


int transport_getdata(unsigned char* buf, int count)
{
	int rc = recv(mysock, buf, count, 0);
	if (rc < 0) {
		/*
		if (errno != EWOULDBLOCK) {
			printf("%s\r\n", "disconnected");
			return -1; //disconnect
		}
		*/
		return 0;
	}
	/*
	printf("received %d bytes count %d\r\n", rc, (int)count);
	printf("%x,%x\r\n", buf[0], buf[1]);
	*/
	return rc;
}

int transport_getdatanb(void *sck, unsigned char* buf, int count)
{
	int sock = *((int *)sck); 	/* sck: pointer to whatever the system may use to identify the transport */
	/* this call will return after the timeout set on initialization if no bytes;
	   in your system you will use whatever you use to get whichever outstanding
	   bytes your socket equivalent has ready to be extracted right now, if any,
	   or return immediately */
	int rc = recv(sock, buf, count, 0);	
	if (rc == -1) {
		/*
		if (errno != EWOULDBLOCK) {
			return -1;
		}
		*/
		/* check error conditions from your system here, and return -1 */
		return 0;
	}
	//printf("transport_getdatanb:%d-%d\r\n", rc, count);
	return rc;
}

/**
return >=0 for a socket descriptor, <0 for an error code
@todo Basically moved from the sample without changes, should accomodate same usage for 'sock' for clarity,
removing indirections
*/
int transport_open(char* addr, int port)
{
	int* sock = &mysock;
	int type = SOCK_STREAM;
	struct sockaddr_in address;
	int rc = -1;
//	sa_family_t family = AF_INET;
	u8_t family = AF_INET;
	static struct timeval tv;

	*sock = -1;
	if (addr[0] == '[')
	  ++addr;

	memset(&address, 0,  sizeof(address));
	address.sin_port = htons(port);
	address.sin_family = family = AF_INET;
	address.sin_addr.s_addr = inet_addr(addr);

	*sock =	socket(family, type, 0);

	if (*sock != -1)
	{
		if (family == AF_INET) {
			rc = connect(*sock, (struct sockaddr*)&address, sizeof(address));
			if (rc != 0) {
				closesocket(*sock);
				return -1;
			} else {
				printf("%s\r\n", "Connected");
			}
		}
	}
	if (mysock == INVALID_SOCKET)
		return rc;

	tv.tv_sec = 1;  /* 1 second Timeout */
	tv.tv_usec = 0;  
	setsockopt(mysock, SOL_SOCKET, SO_RCVTIMEO, (char *)&tv,sizeof(struct timeval));
	return mysock;
}

int transport_close(int sock)
{
	int rc;

	rc = shutdown(sock, SHUT_WR);
	rc = recv(sock, NULL, (size_t)0, 0);
	rc = closesocket(sock);

	return rc;
}
