#include "ethernet.h"
#include "status_codes.h"
#include "conf_uart_serial.h"
#include "uart_serial.h"
#include "stdio_serial.h"
#include "tc.h"

#include "sysclk.h"
#include "lwip/opt.h"
#include "lwip/tcpip.h"

#include "lwip/stats.h"
#include "lwip/sys.h"
#include "lwip/api.h"
#include "lwip/sockets.h"
#include "MQTTPacket.h"
#include "transport.h"

static uint8_t AppVersion[] = "V1.001 #";

static char payload[800];
static unsigned char buf[800];

void user_main(void)
{	
	int rc = 0, mysock = 0, msgid = 1;
	int buflen = sizeof(buf);
	int req_qos[2] = {2, 1};
	
	MQTTPacket_connectData data = MQTTPacket_connectData_initializer;
	MQTTString pub_topicString = MQTTString_initializer;
	MQTTString topicString[2] = { MQTTString_initializer, MQTTString_initializer };

	int payloadlen, len = 0;
	char *host = "23.99.9.16"; //mqtt.linctronix.com
	int port = 1883;
	MQTTTransport mytransport;
	unsigned char dup;
	int qos, payloadlen_in;
	unsigned char retained;
	unsigned char* payload_in;
	MQTTString receivedTopic;
	unsigned short submsgid;
	int subcount, granted_qos, mode, tmpcnt = 0;	
	
	printf("E60 MQTT Receiver %s(%s %s)\r\n", AppVersion, __DATE__, __TIME__);
	printf("Set DHCP mode first please.\r\n");
    while(1) {
	    printf("%s\r\n", "connecting...");
	    mysock = transport_open(host, port);
	    if(mysock >= 0) {
		    break;
	    }
	    vTaskDelay(1000);
    }	

    printf("%s\r\n", "connect ok");
	mode = 1;
	lwip_ioctl(mysock, FIONBIO, &mode);

	mytransport.sck = &mysock;
	mytransport.getfn = transport_getdatanb;
	mytransport.state = 0;
	data.clientID.cstring = "RIO-2014";
	data.keepAliveInterval = 30;
	data.cleansession = 1;

	printf("%d Sending to hostname %s port %d\r\n", mysock, host, port);

	len = MQTTSerialize_connect(buf, buflen, &data);

	rc = transport_sendPacketBuffer(mysock, buf, len);
	printf("transport_send:%d\r\n", rc);

	while (1) {
		// wait for connack
		if (MQTTPacket_read(buf, buflen, transport_getdata) == CONNACK) {
			unsigned char sessionPresent, connack_rc;
			if (MQTTDeserialize_connack(&sessionPresent, &connack_rc, buf, buflen) != 1 || connack_rc != 0) {
				printf("Unable to connect, return code %d\n", connack_rc);
				goto exit;
			} else {
				break;
			}
		}
		vTaskDelay(10);
	}

	// subscribe

	topicString[0].cstring = "RIO-2017/data";
	topicString[1].cstring = "RIO-2018/data";

	/*
	topicString[0].cstring = "RIO-2010/data";
	topicString[1].cstring = "RIO-2010/event";	
	*/
	req_qos[0] = 0;
	req_qos[1] = 0;
	len = MQTTSerialize_subscribe(buf, buflen, 0, msgid, 2, &topicString, &req_qos);

	rc = transport_sendPacketBuffer(mysock, buf, len);

	do {
		int frc;
		if ((frc=MQTTPacket_readnb(buf, buflen, &mytransport)) == SUBACK) {
			// wait for suback
			rc = MQTTDeserialize_suback(&submsgid, 1, &subcount, &granted_qos, buf, buflen);
			if (granted_qos != 0) {
				printf("granted qos != 0, %d\n", granted_qos);
				goto exit;
			}
			break;
		}
		else if (frc == -1) {
			printf("%s\r\n", "frc==-1");
			goto exit;
		}
		vTaskDelay(1);
	} while (1); // handle timeouts here

	// loop getting msgs on subscribed topic
	pub_topicString.cstring = "device_RIO-2015";
	while (1) {
		// handle timeouts
		rc = MQTTPacket_readnb(buf, buflen, &mytransport);
		if (rc == PUBLISH) {
			rc = MQTTDeserialize_publish(&dup, &qos, &retained, &msgid, &receivedTopic,
					&payload_in, &payloadlen_in, buf, buflen);
			printf("publish recv %d\r\n", payloadlen_in);
			payload_in[payloadlen_in] = 0;
			printf("%s\r\n", payload_in);

		} else if (rc == -1) {
			printf("%s\r\n", "disconnected");
			goto exit;
		}
		if ((tmpcnt++) > 0x2000) {
			tmpcnt = 0;
			payloadlen = 0;
			//len = MQTTSerialize_pingreq(buf, 16);
			printf("alive\r\n");

			len = MQTTSerialize_publish(buf, buflen, 0, 0, 0, 0, pub_topicString, (unsigned char*)payload, payloadlen);
	        
	        rc = transport_sendPacketBuffer(mysock, buf, len);

		}
		vTaskDelay(1);
	}
exit:
	transport_close(mysock);
	return -1;
}
