﻿/*
 * RIO2014_NAND_FLASH.h
 *
 * Created: 2015/9/1 下午 08:44:17
 *  Author: Ying
 */ 


#ifndef RIO2014_NAND_FLASH_H_
#define RIO2014_NAND_FLASH_H_

#define	NAND_FLASH_OK						0x00
/* No more blocks can be allocated for a write operation. */
#define NAND_FLASH_ERR_NOMOREBLOCKS			0x01
/* The desired logical block has no current physical mapping. */
#define NAND_FLASH_ERR_BLOCKNOTMAPPED		0x02
/* Access if out-of-bounds. */
#define NAND_FLASH_ERR_OUTOFBOUNDS			0x03
/* There are no block having the desired property. */
#define NAND_FLASH_ERR_NOBLOCKFOUND			0x04
/* The NAND Flash device has no logical mapping information on it. */
#define NAND_FLASH_ERR_MAPPINGNOTFOUND		0x05
/* A read operation cannot be carried out. */
#define NAND_FLASH_ERR_CANNOTREAD			0x06
/* A write operation cannot be carried out. */
#define NAND_FLASH_ERR_CANNOTWRITE			0x07
/* NAND Flash chip model cannot be recognized. */
#define NAND_FLASH_ERR_UNKNOWNMODEL			0x08
/* Page data is corrupted according to ECC */
#define NAND_FLASH_ERR_CORRUPTEDDATA		0x09
/* Block is not in the required status. */
#define NAND_FLASH_ERR_WRONGSTATUS			0x0A
/* Device has no logical mapping stored in it. */
#define NAND_FLASH_ERR_NOMAPPING			0x0B
/* The block being accessed is bad and must be replaced. */
#define NAND_FLASH_ERR_BADBLOCK				0x0C
/* Failed to perform an erase operation. */
#define NAND_FLASH_ERR_CANNOTERASE			0x0D
/* A hardware copyback operation failed. */
#define NAND_FLASH_ERR_CANNOTCOPY			0x0E
/* HW Ecc Not compatible with the NAND Model. */
#define NAND_FLASH_ERR_ECC_NOT_COMPATIBLE	0x0F

uint8_t rio_nand_flash_init(void);
uint8_t rio_nand_flash_erase_block(uint16_t block);
uint8_t rio_nand_flash_write_page(uint16_t block, uint16_t page, uint8_t *data_buf);
uint8_t rio_nand_flash_read_page(uint16_t block, uint16_t page, uint8_t *data_buf);


#endif /* RIO2014_NAND_FLASH_H_ */